<?php
/**
 * 2007-2017 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2017 PrestaShop SA
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */


if (!defined('_PS_VERSION_')) {
    exit;
}
require_once dirname(__FILE__) . '/vendor/autoload.php';

class Liveinform extends Module
{

    protected $config_form = false;

    protected $installer;


    protected function getFields()
    {
        $additionalValues = [
            'payment_method' => 'Метод оплаты',
            'delivery_method' => 'Метод доставки',
            'total_shipping' => 'Сумма доставки',
            'total_discounts' => 'Сумма скидки',
            'address_city' => 'Город доставки',
            'address_index' => 'Индекс доставки',
            'address_street1' => 'Улица доставки',
            'address_street2' => 'Дом',
            'address_company' => 'Название компании',
        ];

        return $fields = [
            'liveinform_api_id' => [
                'label' => 'api_id',
                'type' => 'text'
            ],
            'liveinform_type' => [
                'label' => 'Тип тарифа',
                'type' => 'dropdown',
                'values' => [
                    1 => 'Тариф 1 (10р)',
                    2 => 'Тариф 2 (20р)'
                ]
            ],
            'liveinform_additional1' => [
                'label' => 'Дополнительное поле 1',
                'type' => 'dropdown',
                'values' => $additionalValues
            ],
            'liveinform_additional2' => [
                'label' => 'Дополнительное поле 2',
                'type' => 'dropdown',
                'values' => $additionalValues
            ],
            'liveinform_additional3' => [
                'label' => 'Дополнительное поле 3',
                'type' => 'dropdown',
                'values' => $additionalValues
            ],
            'liveinform_test' => [
                'label' => 'Test mode',
                'type' => 'switch'
            ],
        ];


    }

    public function __construct()
    {
        $this->name = 'liveinform';
        $this->tab = 'shipping_logistics';
        $this->version = '1.0.1';
        $this->author = 'Dmitriy Ronzhin';
        $this->need_instance = 0;

        if (version_compare(_PS_VERSION_, '1.6', '>=')) {
            /**
             * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
             */
            $this->bootstrap = true;
        }

        $this->installer = Hector68\PrestaLiveInform\fabric\InstallFabric::getInstance(_PS_VERSION_, $this);

        parent::__construct();

        $this->displayName = $this->l('liveinform');
        $this->description = $this->l('LiveInform - Tracking orders for e-shops');
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        return parent::install() && $this->installer->getInstall()->install();
    }

    public function uninstall()
    {
        return parent::uninstall() && $this->installer->getInstall()->uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitLiveinformModule')) == true) {
            $this->postProcess();
        }

        $this->context->smarty->assign('module_dir', $this->_path);

        $output = $this->renderForm();

        return $output;
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitLiveinformModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {


        $inputs = [];

        foreach ($this->getFields() as $key => $valueData) {
            switch ($valueData['type']) {
                case 'text':
                    $inputs[] = [
                        'col' => 3,
                        'type' => 'text',
                        'name' => $key,
                        'label' => $this->l($valueData['label']),
                    ];
                    break;
                case 'dropdown':

                    $options = [];

                    foreach ($valueData['values'] as $id_option => $name) {
                        $options[] = [
                            'id_option' => $id_option,
                            'name' => $name
                        ];
                    }
                    $inputs[] = [
                        'type' => 'select',
                        'label' => $this->l($valueData['label']),
                        'name' => $key,
                        'required' => true,
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                        )
                    ];
                    break;
                case 'switch':

                    $inputs[] = [
                        'type' => 'radio',
                        'label' => $this->l($valueData['label']),
                        'name' => $key,
                        'required' => true,
                        'class' => 't',
                        'is_bool' => true,
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ];
                    break;
            }
        }

        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Settings'),
                    'icon' => 'icon-cogs',
                ),
                'input' => $inputs,
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        $result = [];
        $fieldsData = $this->getFields();
        foreach (array_keys($fieldsData) as $fieldKey) {
            $result[$fieldKey] = Configuration::get($fieldKey);
        }
        return $result;
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }


    public function hookDisplayInvoice($params)
    {
        return  $this->installer->getInstall()->displayInvoice($params);
    }

    public function hookDisplayAdminOrder($params)
    {
        return $this->installer->getInstall()->displayAdminOrder($params);
    }
}
